@@ -146,7 +146,7 @@ class SenseTestCase(unittest.TestCase):
     ##
     ##----------------------------------------------------------------------------------------------------------
 
-    def assertFlexSequence(self, commands, pattern):
+    def assertFlexSequence(self, commands, pattern, noticesok=False):
         windowgramgroup_list = WindowgramGroup_Convert.Pattern_To_List( pattern )
         cmdlen, ptnlen = len(commands), len(windowgramgroup_list)
         if cmdlen != ptnlen:
@@ -154,7 +154,7 @@ class SenseTestCase(unittest.TestCase):
         wg = Windowgram( "1" ) # Specified in case the default changes
         wlist = []
         for ix, (command, windowgram) in enumerate( zip( commands, windowgramgroup_list ) ):
-            errors = flex_processor( wg, command )
+            errors = flex_processor( wg, command, noticesok )
             self.assertTrue( not errors, errors )
             self.assertTrue( wg.Export_String() == windowgram, 
                 "The resulting windowgram for sequence #" + str(ix+1) + " does not match: \n\n" + wg.Export_String() )
@@ -411,6 +411,79 @@ class Test_FlexCores(SenseTestCase):
         group_x = scalecore( group_i, 12, 3 )
         self.assertTrue( group_o == group_x )
 
+    ## Enforces the use of scale core v1, and will fail if v2 is reactivated.  See notes in scale core.
+
+    def test_ScaleCoreDifference_CaseOne(self): # Created in flex using "new unittest ScaleCoreDifference_CaseOne"
+        # break 1 2x2 ; scale 3x3 ; scale 2x2
+        wg_i = "01\n23\n"
+        wg_o = scalecore( wg_i, 3, 3 )
+        wg_o = scalecore( wg_o, 2, 2 )
+        self.assertTrue( wg_o == wg_i )
+
+    ## Tests the scale core multiple resizing that's necessary in some situations.  See notes in scale core.
+    ## TODO: Move this into the unit testing for the break command
+
+    def test_ScaleCoreDifference_CaseTwo(self): # Created in flex using "new unittest ScaleCoreDifference_CaseTwo"
+        # scale 42x42 ; break 1 6x6 ; break 1 3x3
+        self.assertFlexSequence( [
+            "scale 42x42 ; break 1 6x6 ; break 1 3x3",
+        ], """
+            000000000111AAABBB222222222333333333444444444555555555
+            000000000111AAABBB222222222333333333444444444555555555
+            000000000111AAABBB222222222333333333444444444555555555
+            000000000CCCDDDEEE222222222333333333444444444555555555
+            000000000CCCDDDEEE222222222333333333444444444555555555
+            000000000CCCDDDEEE222222222333333333444444444555555555
+            000000000FFFGGGHHH222222222333333333444444444555555555
+            000000000FFFGGGHHH222222222333333333444444444555555555
+            000000000FFFGGGHHH222222222333333333444444444555555555
+            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
+            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
+            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
+            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
+            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
+            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
+            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
+            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
+            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
+            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
+            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
+            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
+            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
+            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
+            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
+            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
+            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
+            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
+            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
+            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
+            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
+            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
+            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
+            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
+            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
+            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
+            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
+            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
+            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
+            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
+            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
+            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
+            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
+            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
+            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
+            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
+            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
+            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
+            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
+            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
+            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
+            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
+            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
+            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
+            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
+        """ )
+
     ## Group Core
 
     def test_GroupCore_Sufficient(self):
@@ -453,8 +526,7 @@ class Test_FlexCores(SenseTestCase):
         # SideSwipe algorithm (not to be confused with SwipeSide)
         #
         # This algorithm is axis-agnostic; illustrated tests are vertical, i.e., horizontal swaps parameters.
-        #
-        # To produce these tests, inject the respective windowgram into edgecore() and print the results then exit.
+        # To produce new tests, interject the respective windowgram into edgecore(), print the results, then exit.
         #
         # Successful    Successful    Fail    Fail
         # @A @B @C @D   @E @F @G @H   @I @J   @K @L
@@ -583,6 +655,11 @@ class Test_FlexCores(SenseTestCase):
         self.assertTrue( axis == "v" )
         self.assertTrue( minimal == [ [2, 2, 4] ] )
         self.assertTrue( optimal == [ [2, 1, 4] ] )
+        status, axis, minimal, optimal = edgecore( wg, "X", "right" )
+        self.assertTrue( status is EdgeStatus.Valid )
+        self.assertTrue( axis == "v" )
+        self.assertTrue( minimal == [ [3, 1, 2] ] )
+        self.assertTrue( optimal == [ [3, 0, 5] ] )
 
     def test_EdgeCore_GroupDirection_Horizontal(self):
         wg = Windowgram( """
@@ -594,8 +671,14 @@ class Test_FlexCores(SenseTestCase):
         self.assertTrue( axis == "h" )
         self.assertTrue( minimal == [ [1, 1, 3] ] )
         self.assertTrue( optimal == [ [1, 0, 5] ] )
+        status, axis, minimal, optimal = edgecore( wg, "3", "top" )
+        self.assertTrue( status is EdgeStatus.Valid )
+        self.assertTrue( axis == "h" )
+        self.assertTrue( minimal == [ [1, 0, 2] ] )
+        self.assertTrue( optimal == [ [1, 0, 5] ] )
 
-    def test_EdgeCore_WindowgramEdge(self): # All edges here will be equal, there are no neighbors to extend optimal
+    def test_EdgeCore_WindowgramEdge(self):
+        # All edges here will have equal minimal and optimal since there are no neighboring panes
         wg = Windowgram( """
             011222
             344555
@@ -625,6 +708,116 @@ class Test_FlexCores(SenseTestCase):
         self.assertTrue( minimal == [ [0, 1, 3] ] )
         self.assertTrue( optimal == [ [0, 1, 3] ] )
 
+    def test_EdgeCore_Nuances(self):
+        # This is noncontiguous, for now.  It's possible to support, but callers must be rigorously tested, since they
+        # assume a single run in the edgecore result.
+        wg = Windowgram( """
+            1122AABB
+            aabbxxyy
+            XXYY3344
+        """ )
+        status, axis, minimal, optimal = edgecore( wg, "1234", "right" )
+        self.assertTrue( status is EdgeStatus.Noncontiguous )
+        self.assertTrue( axis is None )
+        self.assertTrue( minimal is None )
+        self.assertTrue( optimal is None )
+
+    def test_EdgeCore_Examples(self):
+        wg = Windowgram( """
+            # E.1
+            aaabbb #
+            111222 # =
+            zzzyyy #
+        """ )
+        status, axis, minimal, optimal = edgecore( wg, "12" )
+        self.assertTrue( status is EdgeStatus.Valid )
+        self.assertTrue( axis is "v" )
+        self.assertTrue( minimal == [ [3, 1, 2] ] )
+        self.assertTrue( optimal == [ [3, 1, 2] ] )
+        wg = Windowgram( """
+            # E.2
+            qqqxxx # o
+            111xxx # o
+            111222 # m
+            111rrr # o
+            wwwrrr # o
+        """ )
+        status, axis, minimal, optimal = edgecore( wg, "12" )
+        self.assertTrue( status is EdgeStatus.Valid )
+        self.assertTrue( axis is "v" )
+        self.assertTrue( minimal == [ [3, 2, 3] ] )
+        self.assertTrue( optimal == [ [3, 0, 5] ] )
+        wg = Windowgram( """
+            # E.3
+            MMMNNN #
+            111OOO # o
+            111222 # m
+            PPP222 # o
+            QQQRRR #
+        """ )
+        status, axis, minimal, optimal = edgecore( wg, "12" )
+        self.assertTrue( status is EdgeStatus.Valid )
+        self.assertTrue( axis is "v" )
+        self.assertTrue( minimal == [ [3, 2, 3] ] )
+        self.assertTrue( optimal == [ [3, 1, 4] ] )
+
+    ## Smudge Core
+
+    def test_SmudgeCore_Basic(self):
+        wg_i = Windowgram( """
+            12345 
+            abcde 
+            fghij 
+            ABCDE 
+            FGHIJ 
+        """ )
+        group_o = """
+            2345 11345 1234 12355
+            bcde aacde abcd abcee
+            ghij ffhij fghi fghjj
+            BCDE AACDE ABCD ABCEE
+            GHIJ FFHIJ FGHI FGHJJ
+
+            abcde 12345 12345 12345 
+            fghij 12345 abcde abcde 
+            ABCDE fghij fghij fghij 
+            FGHIJ ABCDE ABCDE FGHIJ 
+                  FGHIJ       FGHIJ 
+
+            345 12345 123 12555
+            cde abcde abc abeee
+            hij fffij fgh fgjjj
+            CDE AAADE ABC ABCDE
+            HIJ FFFIJ FGH FGHIJ
+
+            fghij 12345 12345 12345 
+            ABCDE ab345 abcde abcde 
+            FGHIJ fg345 fghij FGHij 
+                  ABCDE       FGHDE 
+                  FGHIJ       FGHIJ 
+        """
+        wg_o_list = WindowgramGroup_Convert.Pattern_To_List( group_o )
+        wg_x_list = [
+            smudgecore( wg_i, 0, "v", 1, ""  ).Export_String(),
+            smudgecore( wg_i, 1, "v", 1, ""  ).Export_String(),
+            smudgecore( wg_i, 5, "v", 1, "-" ).Export_String(),
+            smudgecore( wg_i, 4, "v", 1, "-" ).Export_String(),
+            smudgecore( wg_i, 0, "h", 1, ""  ).Export_String(),
+            smudgecore( wg_i, 1, "h", 1, ""  ).Export_String(),
+            smudgecore( wg_i, 5, "h", 1, "-" ).Export_String(),
+            smudgecore( wg_i, 4, "h", 1, "-" ).Export_String(),
+            smudgecore( wg_i, 0, "v", 2, ""  , [0, 1, 4] ).Export_String(), # Edge discarded with transparency
+            smudgecore( wg_i, 1, "v", 2, ""  , [1, 2, 5] ).Export_String(),
+            smudgecore( wg_i, 5, "v", 2, "-" , [5, 1, 4] ).Export_String(), # Edge discarded with transparency
+            smudgecore( wg_i, 4, "v", 2, "-" , [4, 0, 3] ).Export_String(),
+            smudgecore( wg_i, 0, "h", 2, ""  , [0, 1, 4] ).Export_String(), # Edge discarded with transparency
+            smudgecore( wg_i, 1, "h", 2, ""  , [1, 2, 5] ).Export_String(),
+            smudgecore( wg_i, 5, "h", 2, "-" , [5, 1, 4] ).Export_String(), # Edge discarded with transparency
+            smudgecore( wg_i, 4, "h", 2, "-" , [4, 0, 3] ).Export_String(),
+        ]
+        for wg_o, wg_x in zip( wg_o_list, wg_x_list ):
+            self.assertTrue( wg_x == wg_o, "\nwg_o\n" + wg_o + "\nwg_x\n" + wg_x )
+
 
 
 ##----------------------------------------------------------------------------------------------------------------------
@@ -635,80 +828,6 @@ class Test_FlexCores(SenseTestCase):
 
 class Test_FlexModifier_Scale(SenseTestCase):
 
-    ## Enforces the use of scale core v1, and will fail if v2 is reactivated.  See notes in scale core.
-
-    def test_Scale_ScaleCore_CaseOne(self): # Created in flex using "new unittest Scale_ScaleCore_CaseOne"
-        self.assertFlexSequence( [
-            "break 1 2x2 ; scale 3x3 ; scale 2x2",
-        ], """
-            01
-            23
-        """ )
-
-    ## Tests the scale core multiple resizing that's necessary in some situations.  See notes in scale core.
-
-    def test_Scale_ScaleCore_CaseTwo(self): # Created in flex using "new unittest Scale_ScaleCore_CaseTwo"
-        self.assertFlexSequence( [
-            "scale 42x42 ; break 1 6x6 ; break 1 3x3",
-        ], """
-            000000000111AAABBB222222222333333333444444444555555555
-            000000000111AAABBB222222222333333333444444444555555555
-            000000000111AAABBB222222222333333333444444444555555555
-            000000000CCCDDDEEE222222222333333333444444444555555555
-            000000000CCCDDDEEE222222222333333333444444444555555555
-            000000000CCCDDDEEE222222222333333333444444444555555555
-            000000000FFFGGGHHH222222222333333333444444444555555555
-            000000000FFFGGGHHH222222222333333333444444444555555555
-            000000000FFFGGGHHH222222222333333333444444444555555555
-            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
-            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
-            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
-            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
-            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
-            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
-            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
-            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
-            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
-            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
-            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
-            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
-            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
-            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
-            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
-            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
-            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
-            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
-            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
-            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
-            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
-            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
-            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
-            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
-            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
-            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
-            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
-            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
-            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
-            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
-            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
-            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
-            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
-            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
-            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
-            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
-            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
-            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
-            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
-            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
-            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
-            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
-            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
-            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
-            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
-        """ )
-
-    ## General use
-
     def test_Scale_One_DupCharacters(self): # Created in flex using "new unittest Scale_One_DupCharacters"
         self.assertFlexSequence( [
             "scale 1",
@@ -874,6 +993,175 @@ class Test_FlexModifier_Scale(SenseTestCase):
 
 
 
+##----------------------------------------------------------------------------------------------------------------------
+##
+## Unit Testing :: Flex Modifier :: Add
+##
+##----------------------------------------------------------------------------------------------------------------------
+
+class Test_FlexModifier_Add(SenseTestCase):
+
+    def test_Add_Characters(self): # Created in flex using "new unittest Add_Characters"
+        self.assertFlexSequence( [
+            "scale 5x2 ; rename 1 0 ; add left 1 L",
+            "add right 2 R",
+            "add top 3 T",
+            "add bottom 4 B",
+        ], """
+            L00000 L00000RR TTTTTTTT TTTTTTTT
+            L00000 L00000RR TTTTTTTT TTTTTTTT
+                            TTTTTTTT TTTTTTTT
+                            L00000RR L00000RR
+                            L00000RR L00000RR
+                                     BBBBBBBB
+                                     BBBBBBBB
+                                     BBBBBBBB
+                                     BBBBBBBB
+        """ )
+
+    def test_Add_Percentages(self): # Created in flex using "new unittest Add_Percentages"
+        self.assertFlexSequence( [
+            "scale 5 ; rename 1 0 ; add left 100% L",
+            "add right 50% R",
+            "add top 20% T",
+            "add bottom 17% B",
+        ], """
+            LLLLL00000 LLLLL00000RRRRR TTTTTTTTTTTTTTT TTTTTTTTTTTTTTT
+            LLLLL00000 LLLLL00000RRRRR LLLLL00000RRRRR LLLLL00000RRRRR
+            LLLLL00000 LLLLL00000RRRRR LLLLL00000RRRRR LLLLL00000RRRRR
+            LLLLL00000 LLLLL00000RRRRR LLLLL00000RRRRR LLLLL00000RRRRR
+            LLLLL00000 LLLLL00000RRRRR LLLLL00000RRRRR LLLLL00000RRRRR
+                                       LLLLL00000RRRRR LLLLL00000RRRRR
+                                                       BBBBBBBBBBBBBBB
+        """ )
+
+    def test_Add_Multipliers(self): # Created in flex using "new unittest Add_Multipliers"
+        self.assertFlexSequence( [
+            "scale 2 ; rename 1 0 ; add left 3x L",
+            "add right .25x R",
+            "add top .5x T",
+            "add bottom 1x B",
+        ], """
+            LLLLLL00 LLLLLL00RR TTTTTTTTTT TTTTTTTTTT
+            LLLLLL00 LLLLLL00RR LLLLLL00RR LLLLLL00RR
+                                LLLLLL00RR LLLLLL00RR
+                                           BBBBBBBBBB
+                                           BBBBBBBBBB
+                                           BBBBBBBBBB
+        """ )
+
+    def test_Add_DefaultNames(self): # Created in flex using "new unittest Add_DefaultNames"
+        self.assertFlexSequence( [
+            "add left 1",
+            "add right 1",
+            "add right 1",
+            "add right 1",
+            "add right 1",
+            "add right 1",
+            "add right 1",
+            "add right 1",
+            "add right 1",
+            "add top 1",
+            "add bottom 1",
+        ], """
+            01 012 0123 01234 012345 0123456 01234567 012345678 0123456789 aaaaaaaaaa aaaaaaaaaa
+                                                                           0123456789 0123456789
+                                                                                      bbbbbbbbbb
+        """ )
+
+
+
+##----------------------------------------------------------------------------------------------------------------------
+##
+## Unit Testing :: Flex Modifier :: Drag
+##
+##----------------------------------------------------------------------------------------------------------------------
+
+class Test_FlexModifier_Drag(SenseTestCase):
+
+    def test_Drag_EdgeMorphing(self): # Created in flex using "new unittest Drag_EdgeMorphing"
+        self.assertFlexSequence( [
+            "break 1 6x5 a ; join Au.0 Bvp.1 Cwqk.2 Dxrlf.3 s.w t.Q mn.x o.R ghi.y j.S abcd.z e.T y.X z.Y",
+        ], """
+            zzzzT3
+            yyyS23
+            xxR123
+            wQ0123
+            XY0123
+        """ )
+
+    # Ignore notices
+    def test_Drag_EdgeModify_Example1(self): # Created in flex using "new unittest Drag_EdgeModify_Example1"
+        self.assertFlexSequence( [
+            "break 1 6x5 a ; join Au.0 Bvp.1 Cwqk.2 Dxrlf.3 s.w t.Q mn.x o.R ghi.y j.S abcd.z e.T y.X z.Y",
+            "drag XY right 5",
+        ], """
+            zzzzT3 zzzzTT
+            yyyS23 yyySSS
+            xxR123 xxRRRR
+            wQ0123 wQQQQQ
+            XY0123 XXXXXX
+        """, True )
+
+    # Ignore notices
+    def test_Drag_EdgeModify_Example2(self): # Created in flex using "new unittest Drag_EdgeModify_Example2"
+        self.assertFlexSequence( [
+            "break 1 6x5 a ; join Au.0 Bvp.1 Cwqk.2 Dxrlf.3 s.w t.Q mn.x o.R ghi.y j.S abcd.z e.T y.X z.Y",
+            "drag right XY right 4",
+        ], """
+            zzzzT3 zzzzTT
+            yyyS23 yyySSS
+            xxR123 xxRRRR
+            wQ0123 wQQQQQ
+            XY0123 XXXYYY
+        """, True )
+
+    # Ignore notices
+    def test_Drag_EdgeModify_WithScale(self): # Created in flex using "new unittest Drag_EdgeModify_WithScale"
+        self.assertFlexSequence( [
+            "break 1 9x6 ; join RIzqh8 QHypg PGxo OFw NE",
+            "drag right ABCJKL right 6",
+            "drag top * down 100%",
+            "drag left * right 100%",
+        ], """
+            01234567R 012345677 ijklmnnnn m
+            9abcdefQR 9abcdefff
+            ijklmnPQR ijklmnnnn
+            rstuvOPQR rstuvvvvv
+            ABCDNOPQR AAABBBCCC
+            JKLMNOPQR JJJKKKLLL
+        """, True )
+
+    # Ignore notices
+    def test_Drag_EdgeModify_NoScale(self): # Created in flex using "new unittest Drag_EdgeModify_NoScale"
+        self.assertFlexSequence( [
+            "break 1 7x7 ; join 18fm 29g 3a MFyrkd6 LExqjc KDwpi JCvo IBu HA",
+            "drag right l right 10",
+            "drag bottom * up 100%",
+            "drag right * left 100%",
+        ], """
+            012345M 00000000000 lllllllllll l
+            7123bLM 77777777777
+            e12hKLM eeeeeeeeeee
+            l1nJKLM lllllllllll
+            stIJKLM stIIIIIIIII
+            zHIJKLM zHIIIIIIIII
+            GHIJKLM GHIIIIIIIII
+        """, True )
+
+    # Ignore notices
+    def test_Drag_Expansion_Right(self): # Created in flex using "new unittest Drag_Expansion_Right"
+        self.assertFlexSequence( [
+            "break 1 2x3 o ; scale 2x:1x",
+            "drag right q right 5",
+        ], """
+            oopp ooppppp
+            qqrr qqqqqqq
+            sstt ssttttt
+        """, True )
+
+
+
 ##----------------------------------------------------------------------------------------------------------
 ##
 ## Keep this note for adding new unit tests for flex
@@ -886,6 +1174,38 @@ class Test_FlexModifier_Scale(SenseTestCase):
 
 
 
+##----------------------------------------------------------------------------------------------------------------------
+##
+## Unit Testing :: Flex Modifier Combination :: AddBreakJoin
+##
+## This asserts the underlying pane order of [0-9a-zA-Z] through default name assignment of the Add command.  It must
+## follow the commands it depends upon: add, break, and join.
+##
+##----------------------------------------------------------------------------------------------------------------------
+
+class Test_FlexModifierCombination_AddBreakJoin(SenseTestCase):
+
+    def test_AddBreakJoin_DefaultNames(self): # Created in flex using "new unittest AddBreakJoin_DefaultNames"
+        self.assertFlexSequence( [
+            "break 1 31x2 ; join 210 ba BA YZ",
+            "add left 1",
+            "add right 1",
+            "add top 1",
+            "add bottom 1",
+            "add top 1",
+        ], """
+            2223456789bbcdefghijklmnopqrstu 02223456789bbcdefghijklmnopqrstu 02223456789bbcdefghijklmnopqrstu1
+            vwxyzBBCDEFGHIJKLMNOPQRSTUVWXYY 0vwxyzBBCDEFGHIJKLMNOPQRSTUVWXYY 0vwxyzBBCDEFGHIJKLMNOPQRSTUVWXYY1
+
+            aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa ZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZ
+            02223456789bbcdefghijklmnopqrstu1 02223456789bbcdefghijklmnopqrstu1 aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa
+            0vwxyzBBCDEFGHIJKLMNOPQRSTUVWXYY1 0vwxyzBBCDEFGHIJKLMNOPQRSTUVWXYY1 02223456789bbcdefghijklmnopqrstu1
+                                              AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA 0vwxyzBBCDEFGHIJKLMNOPQRSTUVWXYY1
+                                                                                AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
+        """ )
+
+
+
 ##----------------------------------------------------------------------------------------------------------------------
 ##
 ## Unit Testing :: Readme Demonstrations
